#!/bin/bash
# Run the most time consuming LCFI processors on a subset of files
# by protopop@cern.ch - Jul 2013 (PBS version)

events="-1"

if [ "$1" -eq "$1" 2> /dev/null ]; then
  dstmp=`date | awk '{print $2$3}'`
  tag="$1"
  echo "Using run tag $tag"
else
  echo "Please provide a numeric tag!"
  exit 1
fi

cd /afs/phas.gla.ac.uk/user/p/protopop/ILC/analysis/Marlin/ZZfusion/batch

steer="zvKT$tag.xml"
lcout="/afs/phas.gla.ac.uk/data/ilc/datasets01/1.4tev/ZVRES_out/ktfti$tag"_out.slcio
gearx="../gear_ldc.xml"
flist="../steer/lcio_files.xml"

let "n1=$1*10"
let "n2=n1+9"
files=`sed -n "$n1,$n2"p < $flist`

# Template 3 includes the FTI processor as well, and uses FastJet/KT algorithm
cp ../steer/template_03.xml "$steer"
ls -lA

echo "Customising template for this batch run ..."
perl -p -i -e "s#MYNEVENTS#$events#g" $steer
perl -p -i -e "s#MYGEARFILE#$gearx#g" $steer
perl -p -i -e "s#MYLCIOFILES#$files#g" $steer
perl -p -i -e "s#MYVERBOSITY#SILENT#g" $steer
perl -p -i -e "s#MYOUTPUTLCIOFILE#$lcout#g" $steer

echo "Your steering file is $steer "

if [ "1" -eq "1" ]; then
 source /afs/phas.gla.ac.uk/data/ilc/software/ilcsoft/v01-14/init_ilcsoft.sh   
 Marlin $steer >/dev/null 2>&1  
else
 echo "Will not run Marlin"
fi

echo "Run $tag done."

ftstr="ftkt$tag-knets.xml"
echo "Creating $ftstr steering file ..."
cp ft0-pbs-gnets.xml $ftstr
perl -p -i -e "s#fti1#fti$tag#g" $ftstr
perl -p -i -e "s#flavourtag1#flavourtag$tag#g" $ftstr
perl -p -i -e "s#gnets#knets#g" $ftstr

echo "Bye!"
echo
